@@ -120,10 +120,8 @@ plot.mtc.nodesplit <- function(x, ask=dev.interactive(orNone=TRUE), ...) {
   cat("Node-splitting -- convergence plots\n")
   for (name in names(x)) {
     cat(if (name == "consistency") "Consistency model:\n" else paste("Split-node ", name, ":\n", sep=""))
+    if(name != names(x)[1]) par(ask=ask)
     plot(x[[name]], ask=ask, ...)
-    if (ask && name != names(x)[length(x)]) {
-      readline('Hit <Return> to see next plot:')
-    }
   }
 }
 
@@ -189,7 +187,7 @@ plot.mtc.nodesplit.summary <- function(x, ...) {
   t1 <- x[['p.value']][['t1']]
   t2 <- x[['p.value']][['t2']]
   params <- paste('d', t1, t2, sep='.')
-  group.labels <- paste(t1, 'vs', t2)
+  group.labels <- paste(t2, 'vs', t1)
   names(group.labels) <- params
 
   data <- do.call(rbind, lapply(1:length(params), function(i) {
